@@ -29,6 +29,8 @@ import itertools
 import json
 import os
 
+from requests_toolbelt import user_agent
+
 from .constants import API_URLS
 from .models.classic_league import ClassicLeague
 from .models.fixture import Fixture
@@ -38,7 +40,7 @@ from .models.player import Player, PlayerSummary
 from .models.team import Team
 from .models.user import User
 from .utils import (average, fetch, get_current_user, logged_in,
-                    position_converter, scale, team_converter)
+                    position_converter, scale, team_converter, ssl_context)
 from urllib.request import urlopen
 
 
@@ -48,7 +50,7 @@ class FPL:
     def __init__(self, session):
         self.session = session
 
-        resp = urlopen(API_URLS["static"], cafile=certifi.where())
+        resp = urlopen(API_URLS["static"], context=ssl_context)
         static = json.loads(resp.read().decode("utf-8"))
         for k, v in static.items():
             try:
@@ -284,9 +286,9 @@ class FPL:
 
         if not include_summary:
             if player_ids:
-                players = [player for player in players.values() if player["id"] in player_ids]
+                players = [player for player in list(players.values()) if player["id"] in player_ids]
             else:
-                players = players.values()
+                players = list(players.values())
 
             if not return_json:
                 players = [Player(player, self.session) for player in players]
@@ -294,7 +296,7 @@ class FPL:
             return players
 
         if not player_ids:
-            player_ids = [player["id"] for player in players.values()]
+            player_ids = [player["id"] for player in list(players.values())]
 
         tasks = [asyncio.ensure_future(
                  self.get_player(
@@ -406,10 +408,8 @@ class FPL:
 
     async def get_fixtures(self, return_json=False):
         """Returns a list of *all* fixtures.
-
         Information is taken from e.g.:
             https://fantasy.premierleague.com/api/fixtures/
-
         :param return_json: (optional) Boolean. If ``True`` returns a list of
             ``dicts``, if ``False`` returns a list of  :class:`Fixture`
             objects. Defaults to ``False``.
@@ -587,7 +587,9 @@ class FPL:
         }
 
         login_url = "https://users.premierleague.com/accounts/login/"
-        async with self.session.post(login_url, data=payload) as response:
+        async with self.session.post(login_url, data=payload,
+                                     ssl=ssl_context,
+                                     headers={"User-Agent": "Dalvik/2.1.0 (Linux; U; Android 5.1; PRO 5 Build/LMY47D)"}) as response:
             state = response.url.query["state"]
             if state == "fail":
                 reason = response.url.query["reason"]
