@@ -1,5 +1,6 @@
 import aiohttp
 import pytest
+import os
 
 from fpl import FPL
 from fpl.models import Fixture, H2HLeague, User, ClassicLeague, Team, Gameweek
@@ -10,6 +11,24 @@ from tests.test_team import team_data
 from tests.test_user import user_data
 from tests.test_gameweek import gameweek_data
 
+try:
+    from.temp_env_var import TEMP_ENV_VARS, ENV_VARS_TO_SUSPEND
+except ImportError:
+    TEMP_ENV_VARS = {}
+    ENV_VARS_TO_SUSPEND = []
+
+@pytest.fixture(scope="session", autouse=True)
+def tests_setup_and_teardown():
+    # Will be executed before the first test
+    old_environ = dict(os.environ)
+    os.environ.update(TEMP_ENV_VARS)
+    for env_var in ENV_VARS_TO_SUSPEND:
+        os.environ.pop(env_var, default=None)
+
+    yield
+    # Will be executed after the last test
+    os.environ.clear()
+    os.environ.update(old_environ)
 
 @pytest.fixture()
 async def fpl():
